@@ -118,6 +118,7 @@ def duration_scan(detectors, *args, duration=0, per_step=None, md=None):
 
     _md['hints'] = default_hints
     _md['hints'].update(md.get('hints', {}) or {})
+    _md['disable_plots'] = True
     # end borrowed md handling block
 
     @bpp.stage_decorator(detectors + motors)
@@ -454,7 +455,8 @@ def daq_list_scan(*args, per_step=None, md=None):
 
 @bpp.reset_positions_decorator()
 @nbpp.daq_step_scan_decorator
-def daq_ascan(detectors, motor, start, end, nsteps):
+@nbpp.step_size_decorator
+def daq_ascan(detectors, motor, start, end, n):
     """
     One-dimensional daq scan with absolute positions.
 
@@ -476,8 +478,9 @@ def daq_ascan(detectors, motor, start, end, nsteps):
     end : int or float
         The last point in the scan.
 
-    nsteps : int
-        The number of points in the scan.
+    n : int or float
+        if int, the number of points in the scan.
+        if float, step size
 
     events : int, optional
         Number of events to take at each step. If omitted, uses the
@@ -501,13 +504,14 @@ def daq_ascan(detectors, motor, start, end, nsteps):
     :py:func:`nabs.preprocessors.daq_step_scan_decorator`.
     """
 
-    yield from bp.scan(detectors, motor, start, end, nsteps)
+    yield from bp.scan(detectors, motor, start, end, n)
 
 
 @bpp.reset_positions_decorator()
 @bpp.relative_set_decorator()
 @nbpp.daq_step_scan_decorator
-def daq_dscan(detectors, motor, start, end, nsteps):
+@nbpp.step_size_decorator
+def daq_dscan(detectors, motor, start, end, n):
     """
     One-dimensional daq scan with relative (delta) positions.
 
@@ -529,8 +533,9 @@ def daq_dscan(detectors, motor, start, end, nsteps):
     end : int or float
         The last point in the scan, relative to the current position.
 
-    nsteps : int
-        The number of points in the scan.
+    n : int or float
+        if int, the number of points in the scan.
+        if float, step size
 
     events : int, optional
         Number of events to take at each step. If omitted, uses the
@@ -554,7 +559,7 @@ def daq_dscan(detectors, motor, start, end, nsteps):
     :py:func:`nabs.preprocessors.daq_step_scan_decorator`.
     """
 
-    yield from bp.scan(detectors, motor, start, end, nsteps)
+    yield from bp.scan(detectors, motor, start, end, n)
 
 
 @bpp.reset_positions_decorator()
@@ -618,6 +623,67 @@ def daq_a2scan(detectors, m1, a1, b1, m2, a2, b2, nsteps):
     yield from bp.scan(detectors, m1, a1, b1, m2, a2, b2, nsteps)
 
 
+@bpp.reset_positions_decorator()
+@bpp.relative_set_decorator()
+@nbpp.daq_step_scan_decorator
+def daq_d2scan(detectors, m1, a1, b1, m2, a2, b2, nsteps):
+    """
+    Two-dimensional daq scan with relative positions
+
+    This moves two motors from start to end relative to their current positions
+    in nsteps steps, taking data in the DAQ at every step, and returning the
+    motors to their original positions at the end of the scan.
+
+    Parameters
+    ----------
+    detectors : list of readables
+        Objects to read into Python in the scan.
+
+    m1 : Movable
+        The first movable object to scan.
+
+    a1 : int or float
+        The first point in the scan for m1, relative to the current position.
+
+    b1 : int or float
+        The last point in the scan for m1, relative to the current position.
+
+    m2 : Movable
+        The second movable object to scan.
+
+    a2 : int or float
+        The first point in the scan for m2, relative to the current position.
+
+    b2 : int or float
+        The last point in the scan for m2, relative to the current position.
+
+    nsteps : int
+        The number of points in the scan.
+
+    events : int, optional
+        Number of events to take at each step. If omitted, uses the
+        duration argument or the last configured value.
+
+    duration : int or float, optional
+        Duration of time to spend at each step. If omitted, uses the events
+        argument or the last configured value.
+
+    record : bool, optional
+        Whether or not to record the run in the DAQ. Defaults to True because
+        we don't want to accidentally skip recording good runs.
+
+    use_l3t : bool, optional
+        Whether or not the use the l3t filter for the events argument. Defaults
+        to False to avoid confusion from unconfigured filters.
+
+    Note
+    ----
+    The events, duration, record, and use_l3t arguments come from the
+    :py:func:`nabs.preprocessors.daq_step_scan_decorator`.
+    """
+    yield from bp.scan(detectors, m1, a1, b1, m2, a2, b2, nsteps)
+
+
 @bpp.reset_positions_decorator()
 @nbpp.daq_step_scan_decorator
 def daq_a3scan(detectors, m1, a1, b1, m2, a2, b2, m3, a3, b3, nsteps):
@@ -688,6 +754,123 @@ def daq_a3scan(detectors, m1, a1, b1, m2, a2, b2, m3, a3, b3, nsteps):
     yield from bp.scan(detectors, m1, a1, b1, m2, a2, b2, m3, a3, b3, nsteps)
 
 
+@bpp.reset_positions_decorator()
+@nbpp.daq_step_scan_decorator
+def daq_anscan(detectors, *args):
+    """
+    N-dimensional daq scan with absolute positions.
+
+    This moves N motors from start to end in nsteps steps, taking data in
+    the DAQ at every step, and returning the motors to their original positions
+    at the end of the scan.
+
+    Takes an arbitrary number of motors, start and stop positions
+
+    >> RE(daq_anscan([], m1, a1, b1,
+                         m2, a2, b2, ... ,
+                         mn, an, bn, nsteps,
+                         events=10))
+
+    Parameters
+    ----------
+    detectors : list of readables
+        Objects to read into Python in the scan.
+
+    m1 : Movable
+        The first movable object to scan.
+
+    a1 : int or float
+        The first point in the scan for m1.
+
+    b1 : int or float
+        The last point in the scan for m1.
+
+    nsteps : int
+        The number of points in the scan.
+
+    events : int, optional
+        Number of events to take at each step. If omitted, uses the
+        duration argument or the last configured value.
+
+    duration : int or float, optional
+        Duration of time to spend at each step. If omitted, uses the events
+        argument or the last configured value.
+
+    record : bool, optional
+        Whether or not to record the run in the DAQ. Defaults to True because
+        we don't want to accidentally skip recording good runs.
+
+    use_l3t : bool, optional
+        Whether or not the use the l3t filter for the events argument. Defaults
+        to False to avoid confusion from unconfigured filters.
+
+    Note
+    ----
+    The events, duration, record, and use_l3t arguments come from the
+    :py:func:`nabs.preprocessors.daq_step_scan_decorator`.
+    """
+    yield from bp.scan(detectors, *args)
+
+
+@bpp.reset_positions_decorator()
+@bpp.relative_set_decorator()
+@nbpp.daq_step_scan_decorator
+def daq_dnscan(detectors, *args):
+    """
+    N-dimensional daq scan with relative positions.
+
+    This moves N motors from start to end in nsteps steps, taking data in
+    the DAQ at every step, and returning the motors to their original positions
+    at the end of the scan.
+
+    Takes an arbitrary number of motors, start and stop positions
+
+    >> RE(daq_dnscan([], m1, a1, b1,
+                         m2, a2, b2, ... ,
+                         mn, an, bn, nsteps,
+                         events=10))
+
+    Parameters
+    ----------
+    detectors : list of readables
+        Objects to read into Python in the scan.
+
+    m1 : Movable
+        The first movable object to scan.
+
+    a1 : int or float
+        The first point in the scan for m1, relative to the current position.
+
+    b1 : int or float
+        The last point in the scan for m1, relative to the current position.
+
+    nsteps : int
+        The number of points in the scan.
+
+    events : int, optional
+        Number of events to take at each step. If omitted, uses the
+        duration argument or the last configured value.
+
+    duration : int or float, optional
+        Duration of time to spend at each step. If omitted, uses the events
+        argument or the last configured value.
+
+    record : bool, optional
+        Whether or not to record the run in the DAQ. Defaults to True because
+        we don't want to accidentally skip recording good runs.
+
+    use_l3t : bool, optional
+        Whether or not the use the l3t filter for the events argument. Defaults
+        to False to avoid confusion from unconfigured filters.
+
+    Note
+    ----
+    The events, duration, record, and use_l3t arguments come from the
+    :py:func:`nabs.preprocessors.daq_step_scan_decorator`.
+    """
+    yield from bp.scan(detectors, *args)
+
+
 def fixed_target_scan(sample, detectors, x_motor, y_motor, scan_motor, ss,
                       n_shots, path):
     """
